#!/bin/sh
# create dummy .i from each service present in /etc/rc.d/init.d

blacklisted() {
	case "$s" in
	killall | allowlogin | sys-chroots | random | single | \
	cups | qmail )
		return 0
		;;
	esac
	return 1
}

add() {
	local s=$1
	local pkg=$2
	local svc=$3

	if [ -f $svc.i ]; then
		echo >&2 "Abourt: $svc already exists!"
		exit 1
	fi

	echo "%_initng_service_hook -p $pkg $svc" >> deps.spec
	cat > $svc.i <<EOF
# Autogenerated by $0 on $(LC_ALL=C date)
service $svc {
	need = system/initial system/mountfs system/network system/rundir

	exec start = /etc/rc.d/init.d/$s;
	exec_args start = start;
	exec stop = /etc/rc.d/init.d/$s;
	exec_args stop = stop;
}
EOF
}

for f in $(find /etc/rc.d/init.d -type f -perm +100); do
	pkg=$(rpm --qf '%{name}\n' -qf $f 2>/dev/null | grep -v 'is not')
	[ "$pkg" ] || continue
	s=$(basename "$f")

	blacklisted && continue

	# skip direct match
	[ -f daemon/$s.i -o -f net/$s.i ] && continue

	svc="daemon/$s"

	# skip ones that are calling directly init.d script
	have=$(grep init.d/$s {net,daemon}/*.i | wc -l)
	[ $have -gt 0 ] && continue

	# skip with processname
	procnames=$(awk '/^#.*processname:/{print $NF}' $f)
	if [ "$procnames" ]; then
		break=0
		for p in $procnames; do
			[ -f daemon/$p.i -o -f net/$p.i ] && break=1
			svc="daemon/$p"
		done
		[ $break = 1 ] && continue
	fi

	echo "Adding $s ($pkg) as $svc"
	add $s $pkg $svc
done
